@@ -25,17 +25,26 @@ class SSHResponse:
         self.command = command
 
     def __str__(self):
-        dict_ = self.dict
-        return json.dumps(dict_, indent=4)
+        return json.dumps(self._dict, indent=4)
 
     @property
-    def stdout(self) -> None | str | dict | list:
+    def stdout(self):
+        """STDOUT
+
+        Can be:
+            - None
+            - str
+            - dict
+            - list
+        """
+
         out = self.__out
         try:
             out = json.loads(out)
         except (TypeError, JSONDecodeError):
             ...
-        return out if out else None
+
+        return out
 
     @property
     def stderr(self) -> None | str:
@@ -51,7 +60,7 @@ class SSHResponse:
         return self.exited == 0
 
     @property
-    def dict(self):
+    def _dict(self):
         """Get raw response from WinRM and return result dict"""
 
         result = {
@@ -725,28 +734,12 @@ class Plinux:
             return os.path.exists(path)
         raise SyntaxError('Incorrect method usage. Check specified path.')
 
-    def cat_file(self, path: str, sudo: bool = False) -> str | dict:
+    def cat_file(self, path: str, sudo: bool = False, pprint: bool = False) -> str | dict:
         """Get file content"""
 
-        self.logger.warning(f'Method will be deprecated in the next release. Use .cat()')
-
         cmd = f'cat {path}'
         result = self.run_cmd(cmd, sudo=sudo)
-        return result.stdout
-
-    def get_json(self, path: str, sudo: bool = False, pprint: bool = False, remove_bom: bool = False) -> dict:
-        """Read JSON file as string and pretty print it into console
-
-        Args:
-            path: Full file path
-            sudo: Use sudo
-            pprint: pretty print into console
-            remove_bom: Remove Byte Order Mark
-        """
-
-        file = self.cat_file(path, sudo=sudo)
-        if remove_bom:
-            file = file.encode().decode('utf-8-sig')
+        file = result.stdout
 
         if pprint:
             print(json.dumps(file, indent=4), sep='')
@@ -1203,7 +1196,7 @@ class Plinux:
         """Get directory size
 
         Command:
-            - du -sh -b /mnt/ssd-cache | awk {'print $1'}
+            - du -s --block-size=1 /mnt/ssd-cache | awk {'print $1'}
 
         Args:
             path: /mnt/ssd-cache/
@@ -1213,15 +1206,15 @@ class Plinux:
             Size in bytes
         """
 
-        cmd = f"du -sh -b {path} | awk {{'print $1'}}"
-        result = self.run_cmd(cmd, sudo=sudo).stdout  # 876592118	/mnt/ssd-cache/
-        print(result)
+        cmd = f"du -s --block-size=1 {path} | awk {{'print $1'}}"
+        result = self.run_cmd(cmd, sudo=sudo).stdout  # 876592118
 
-        try:
+        try:  # Use try-block to process invalid paths. Returns string if path is invalid
             return int(result)
-        except TypeError as err:
-            self.logger.exception(f'Path ({path}) not found or something went wrong.')
-            raise err
+        except ValueError:
+            msg = f'Path ({path}) not found or something went wrong.'
+            self.logger.exception(msg)
+            raise RemoteCommandExecutionError(msg)
 
     def get_port_listeners_process_id(self, port: int) -> Union[int, list[int]]:
         r"""Get processes ids of port listeners
